#define _IN_OPTICALPARA_C
#include "opticalpara.h"
#if (CUR_MACHINE == MACH_OPTICAL)

void InitOpticalPara(void)
{
	// 注册参数名称
	SetMcParaNameString((void*)(&g_opticalMcParastrlist));
	SetWkParaNameString((void*)(&g_opticalWkParastrlist));

	// 注册参数列表
	SetMcParaList((void*)(&g_defOpticalMcParaList));
	SetWkParaList((void*)(&g_defOpticalWkParaList));

	// 参数范围检测
	CheckMcParaRange();
	CheckWkParaRange();
}
#endif// (CUR_MACHINE == MACH_OPTICAL)
